==> openshift-model-monitoring-5.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RelabelConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RelabelConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigBuilder>{
  public RelabelConfigBuilder() {
    this(false);
  }
  public RelabelConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new RelabelConfig(), validationEnabled);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RelabelConfig(), validationEnabled);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this(fluent, instance, false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withModulus(instance.getModulus()); 
    fluent.withRegex(instance.getRegex()); 
    fluent.withReplacement(instance.getReplacement()); 
    fluent.withSeparator(instance.getSeparator()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withTargetLabel(instance.getTargetLabel()); 
    this.validationEnabled = validationEnabled; 
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this(instance,false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withModulus(instance.getModulus()); 
    this.withRegex(instance.getRegex()); 
    this.withReplacement(instance.getReplacement()); 
    this.withSeparator(instance.getSeparator()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withTargetLabel(instance.getTargetLabel()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig build() {
    RelabelConfig buildable = new RelabelConfig(fluent.getAction(),fluent.getModulus(),fluent.getRegex(),fluent.getReplacement(),fluent.getSeparator(),fluent.getSourceLabels(),fluent.getTargetLabel());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RelabelConfigBuilder that = (RelabelConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RelabelConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RelabelConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigBuilder>{
  public RelabelConfigBuilder() {
    this(false);
  }
  public RelabelConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new RelabelConfig(), validationEnabled);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RelabelConfig(), validationEnabled);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this(fluent, instance, false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withModulus(instance.getModulus()); 
    fluent.withRegex(instance.getRegex()); 
    fluent.withReplacement(instance.getReplacement()); 
    fluent.withSeparator(instance.getSeparator()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withTargetLabel(instance.getTargetLabel()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this(instance,false);
  }
  public RelabelConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withModulus(instance.getModulus()); 
    this.withRegex(instance.getRegex()); 
    this.withReplacement(instance.getReplacement()); 
    this.withSeparator(instance.getSeparator()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withTargetLabel(instance.getTargetLabel()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig build() {
    RelabelConfig buildable = new RelabelConfig(fluent.getAction(),fluent.getModulus(),fluent.getRegex(),fluent.getReplacement(),fluent.getSeparator(),fluent.getSourceLabels(),fluent.getTargetLabel());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RelabelConfigBuilder that = (RelabelConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
